@@ -10,6 +10,7 @@ from sqlalchemy.exc import IntegrityError
 from cryptography.fernet import Fernet
 import pymysql
 import random
+import math
 
 """# SAFFRONSTAYS
 
@@ -125,7 +126,28 @@ def ss_fb_catalogue():
 
 # Return list of all locations
 def vista_locations():
-  locations = ["lonavala, maharashtra","goa, goa","alibaug, maharashtra","nainital, uttarakhand","chail, himanchal-pradesh","manali, himachal-pradesh","shimla, himanchal%20pradesh","ooty, tamil%20nadu","coorg, karnataka","dehradun, uttarakhand","jaipur, rajasthan","udaipur, rajasthan","mahabaleshwar, maharashtra","nashik, maharashtra"]
+  locations = ["lonavala, maharashtra",
+  "goa, goa",
+  "alibaug, maharashtra",
+  "nainital, uttarakhand",
+  "chail, himanchal-pradesh",
+  "manali, himachal-pradesh",
+  "shimla, himanchal%20pradesh",
+  "ooty, tamil%20nadu",
+  "coorg, karnataka",
+  "dehradun, uttarakhand",
+  "jaipur, rajasthan",
+  "udaipur, rajasthan",
+  "mahabaleshwar, maharashtra",
+  "nashik, maharashtra",
+  "kerala, kerala",
+  "gangtok, sikkim",
+  "gurgaon, haryana",
+  "vadodara, gujarat",
+  "kashmir, jammu"
+  ]
+
+
   return locations
 
 # Wrapper on the search API
@@ -528,6 +550,63 @@ def vista_weekly_update_script(cypher_key,search_api_wait=10):
 
   return final_success_response
 
+# Breadth first seach algorithm to see the blocekd dates
+def vista_blocked_dates(property_id,ci,co):
+  rg = (datetime.datetime.strptime(co, "%Y-%m-%d") - datetime.datetime.strptime(ci, "%Y-%m-%d")).days    #Range
+
+  steps = 0
+
+  DTE = [(ci,co,rg)]                  # This list will contain all the date ranges to be checked - there will be additions and subtractions to this list
+
+  blocked = []
+  explored = []
+
+  while len(DTE) != 0:
+
+    steps += 1
+
+    print("Dates to Check: ", DTE)
+    dates = DTE.pop()
+
+    explored.append(dates)
+
+    checkin = dates[0]
+    checkout = dates[1]
+    range = dates[2]
+
+    api_response = vista_price_calculator_api(property_id=property_id,checkin=checkin,checkout=checkout)
+
+    if "error" not in api_response.keys():
+      continue
+
+    else:
+      if range == 1:
+        blocked.append((checkin,api_response['data']['price']['amount_to_be_paid']))
+      else:
+        checkin_t = datetime.datetime.strptime(checkin, "%Y-%m-%d")
+        checkout_t = datetime.datetime.strptime(checkout, "%Y-%m-%d")
+
+        middle_date = checkin_t + datetime.timedelta(math.ceil(range/2))
+
+        first_half = ( str(checkin_t)[:10] , str(middle_date)[:10] , (middle_date - checkin_t).days )
+        second_half = ( str(middle_date)[:10] , str(checkout_t)[:10] , (checkout_t - middle_date).days)
+
+        DTE.extend([first_half,second_half])
+
+
+  response_obj = {
+      "blocked_dates_and_price" : blocked,
+      "meta_data": {
+          "total_blocked_dates" : len(blocked),
+          "api_calls":steps,
+          "from": ci,
+          "to":co
+          #"date_ranges_checked":explored
+      }
+  }
+
+  return response_obj
+
 """# Lohono
 
 
@@ -671,13 +750,14 @@ mock_proxy()
 ```
 """
 
-# Get the next weekday ( 0 = monday (default) , 1 = tuesday ... )
+# Get the next weekday ( 0=monday , 1 = tuesday ... )
 def next_weekday(weekday=0, d=datetime.date.today()):
     days_ahead = weekday - d.weekday()
     if days_ahead <= 0: # Target day already happened this week
         days_ahead += 7
     return d + datetime.timedelta(days_ahead)
 
+# default - next monday
 
 # gives a random user-agent to use in the API call
 def mock_user_agent():
